===========
Jaffle Apps
===========

Built-in Apps
=============

.. toctree::
   :maxdepth: 1

   watchdog
   pytest
   tornado

Custom Apps
===========

You can create your own Jaffle app by inheriting :ref:`base_jaffle_app`.
See :doc:`/devel/index` for more information.
